| plot_popn | R Documentation |
Plot time series of population size using model outputs.
plot_popn(
resdf,
selectPopn = c("L", "L_1", "L_2", "L_3", "L_4", "L_5", "M"),
include_temp = TRUE,
include_plasmod = TRUE,
MTT = NULL,
MTD = NULL
)
resdf |
Results dataframe generated by mosqmod::runModel(). |
selectPopn |
Character vector of population component to plot (options are "L", "L_1", "L_2", "L_3", "L_4", "L_5" or "M"). |
include_temp |
Include a plot facet of temperature time series (default = TRUE). |
include_plasmod |
Include (default = TRUE) shaded regions on plot when temperatures are suitable for plasmodium development. |
MTT |
Display minimum temperature threshold for mosquito development. |
MTD |
Display minimum temperature threshold for plasmodium sporogeny. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.